@@ -1,12 +1,12 @@
 use 5.008001; # sane UTF-8 support
 use strict;
 use warnings;
-package YAML::Tiny; # git description: v1.66-5-ge09e1ae
+package YAML::Tiny; # git description: v1.74-6-g56f1f15
 # XXX-INGY is 5.8.1 too old/broken for utf8?
 # XXX-XDG Lancaster consensus was that it was sufficient until
 # proven otherwise
 
-our $VERSION = '1.67';
+our $VERSION = '1.75';
 
 #####################################################################
 # The YAML::Tiny API.
@@ -138,7 +138,10 @@ my %UNESCAPES = (
 # These 3 values have special meaning when unquoted and using the
 # default YAML schema. They need quotes if they are strings.
 my %QUOTE = map { $_ => 1 } qw{
-    null true false
+    null Null NULL
+    y Y yes Yes YES n N no No NO
+    true True TRUE false False FALSE
+    on On ON off Off OFF
 };
 
 # The commented out form is simpler, but overloaded the Perl regex
@@ -373,7 +376,7 @@ sub _load_scalar {
     while ( @$lines ) {
         $lines->[0] =~ /^(\s*)/;
         last unless length($1) >= $indent->[-1];
-        push @multiline, substr(shift(@$lines), length($1));
+        push @multiline, substr(shift(@$lines), $indent->[-1]);
     }
 
     my $j = (substr($string, 0, 1) eq '>') ? ' ' : "\n";
@@ -569,10 +572,8 @@ sub _dump_file {
     if ( _can_flock() ) {
         # Open without truncation (truncate comes after lock)
         my $flags = Fcntl::O_WRONLY()|Fcntl::O_CREAT();
-        sysopen( $fh, $file, $flags );
-        unless ( $fh ) {
-            $self->_error("Failed to open file '$file' for writing: $!");
-        }
+        sysopen( $fh, $file, $flags )
+            or $self->_error("Failed to open file '$file' for writing: $!");
 
         # Use no translation and strict UTF-8
         binmode( $fh, ":raw:encoding(UTF-8)");
@@ -878,7 +879,7 @@ YAML::Tiny - Read/Write YAML files with as little code as possible
 
 =head1 VERSION
 
-version 1.67
+version 1.75
 
 =head1 PREAMBLE
 
@@ -897,7 +898,7 @@ Like the other C<::Tiny> modules, YAML::Tiny has no non-core dependencies,
 does not require a compiler to install, is back-compatible to Perl v5.8.1,
 and can be inlined into other modules if needed.
 
-In exchange for this adding this extreme flexibility, it provides support
+In exchange for adding this extreme flexibility, it provides support
 for only a limited subset of YAML. But the subset supported contains most
 of the features for the more common uses of YAML.
 
@@ -1363,8 +1364,8 @@ Support for the document boundary marker "---" is required.
 
 Support for the document boundary market "..." is B<not> required.
 
-If necessary, a document boundary should simply by indicated with a
-"---" marker, with not preceding "..." marker.
+If necessary, a document boundary should simply be indicated with a
+"---" marker, with no preceding "..." marker.
 
 Support for empty streams (containing no documents) is required.
 
